@@ -226,7 +226,11 @@ class Package(ModuleType):
             if (rpyname != rname) and (rname in self._exported_names):
                 self._exported_names.remove(rname)
                 self._exported_names.add(rpyname)
-            rpyobj = conversion.ri2ro(self._env[rname])
+            try:
+                riobj = self._env[rname]
+            except rinterface.RRuntimeError as rre:
+                warn(str(rre))
+            rpyobj = conversion.ri2ro(riobj)
             if hasattr(rpyobj, '__rname__'):
                 rpyobj.__rname__ = rname
             #FIXME: shouldn't the original R name be also in the __dict__ ?
